bayespy.inference.vmp.nodes.bernoulli.BernoulliDistribution.compute_fixed_moments_and_f
=======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliDistribution.compute_fixed_moments_and_f